Gestione club — SoL 4, manuale utente

# Gestione club

Un club è l'entità che organizza uno o più campionati di tornei. Può anche avere un elenco di giocatori associati.

Un club può anche essere una federazione nazionale, che solitamente coordina vari club di un certo paese. Molto spesso i tornei internazionali vengono ospitati a turno da questa o quella federazione e in genere è richiesto che i partecipanti a questi tornei siano affiliati a una particolare federazione.

Indice

- Gestione club

  - Voci del menu

  - Inserimento e modifica

    - Descrizione

    - Nazionalità, sito web e email

    - Federazioni

    - Abbinamenti e premiazioni

    - Responsabile

    - Stemma

## Voci del menu

Oltre alle azioni standard il menu contiene queste voci:

Gestione club

Campionati

  Apre la gestione dei campionati organizzati dal club selezionato

Giocatori

  Apre la gestione dei giocatori associati al club selezionato

Scarica

  Permette di scaricare i dati di tutti i tornei organizzati dal club selezionato

Assegna

  Assegna la responsabilità dei club selezionati: è possibile selezionare uno o più club tenendo premuto il tasto `Ctrl` ed estendere la selezione premendo il tasto `Shift`

## Inserimento e modifica

### Descrizione

Ogni club ha una descrizione che deve essere univoca: non ci possono essere due club con la stessa descrizione.

### Nazionalità, sito web e email

Sia nazionalità, che URL del sito web che email sono facoltativi. Quest'ultimo può essere eventualmente utilizzato per inviare messaggi di posta elettronica al responsabile del club.

### Federazioni

Un club può essere contrassegnato come federazione: per poter partecipare a tornei internazionali spesso si richiede che il singolo giocatore sia affiliato ad una federazione nazionale.

### Abbinamenti e premiazioni

Il metodo abbinamenti e il metodo premiazione sono usati come valori di default nella creazione di nuovi campionati organizzati dal club.

### Responsabile

Il responsabile generalmente indica l'utente che ha inserito quel particolare club: i dati del club potranno essere modificati solo da lui (oltre che dall'amministratore del sistema.).

### Stemma

Ad ogni club può essere assegnata un'immagine (nei formati `.png`, `.jpg` o `.gif`) utilizzata come stemma che verrà stampato sulle Tessere personali. Sebbene venga automaticamente scalata alla bisogna, si raccomanda di usare immagini di dimensioni ragionevoli (di fatto il programma impone un limite di 256Kb).